bev <- stats::ts(c(
17,
19,
20,
15,
13,
14,
14,
14,
14,
11,
16,
19,
23,
18,
17,
20,
20,
18,
14,
16,
21,
24,
15,
16,
20,
14,
16,
25.5,
25.8,
26,
26,
29,
20,
18,
16,
22,
22,
16,
19,
17,
17,
19,
20,
24,
28,
36,
20,
14,
18,
27,
29,
36,
29,
27,
30,
38,
50,
24,
25,
30,
31,
37,
41,
36,
32,
47,
42,
37,
34,
36,
43,
55,
64,
79,
59,
47,
48,
49,
45,
53,
55,
55,
54,
56,
52,
76,
113,
68,
59,
74,
78,
69,
78,
73,
88,
98,
109,
106,
87,
77,
77,
63,
70,
70,
63,
61,
66,
78,
93,
97,
77,
83,
81,
82,
78,
75,
80,
87,
72,
65,
74,
91,
115,
99,
99,
115,
101,
90,
95,
108,
147,
112,
108,
99,
96,
102,
105,
114,
103,
98,
103,
101,
110,
109,
98,
84,
90,
120,
124,
136,
120,
135,
100,
70,
60,
72,
70,
71,
94,
95,
110,
154,
116,
99,
82,
76,
64,
63,
68,
64,
67,
71,
72,
89,
114,
102,
85,
88,
97,
94,
88,
79,
74,
79,
95,
70,
72,
63,
60,
74,
75,
91,
126,
161,
109,
108,
110,
130,
166,
143,
103,
89,
76,
93,
82,
71,
69,
75,
134,
183,
113,
108,
121,
139,
109,
90,
88,
88,
93,
106,
89,
79,
91,
96,
111,
112,
104,
94,
98,
88,
94,
81,
77,
84,
92,
96,
102,
95,
98,
125,
162,
113,
94,
85,
89,
109,
110,
109,
120,
116,
101,
113,
109,
105,
94,
102,
141,
135,
118,
115,
111,
127,
124,
113,
122,
130,
137,
148,
142,
143,
176,
184,
164,
146,
147,
124,
119,
135,
125,
116,
132,
133,
144,
145,
146,
138,
139,
154,
181,
185,
151,
139,
157,
155,
191,
248,
185,
168,
176,
243,
289,
251,
232,
207,
276,
250,
216,
205,
206,
208,
226,
302,
261,
207,
209,
280,
381,
266,
197,
177,
170,
152,
156,
141,
142,
137,
161,
189,
226,
194,
217,
199,
151,
144,
138,
145,
156,
184,
216,
204,
186,
197,
183,
175,
183,
230,
278,
179,
161,
150,
159,
180,
223,
294,
300,
297,
232,
179,
180,
215,
258,
236,
202,
174,
179,
210,
268,
267,
208,
224),
start = 1500, end = 1869, frequency = 1)
